class CardNotFound(Exception):
    pass


class CardIdAlreadyUsed(Exception):
    pass


class CellNotFound(Exception):
    pass


class CellIdAlreadyUsed(Exception):
    pass


class SurfNotFound(Exception):
    pass


class SurfIdAlreadyUsed(Exception):
    pass


class MaterialNotFound(Exception):
    pass


class MaterialIdAlreadyUsed(Exception):
    pass


class TransformationNotFound(Exception):
    pass


class TransformationIdAlreadyUsed(Exception):
    pass


class NotImplementedFeature(Exception):
    pass


class ParameterError(Exception):
    pass


class ParticleParameterError(Exception):
    pass
